/*
 * Connect notification dialog
 *  for Wi-Fi view & select
 */
package jp.gr.java_conf.j_sota.wifiviewandselect;

import android.app.Activity;
import android.app.Dialog;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.TextView;

public class ConnectNotifyDialog extends DialogFragment {

	/**
	 * Button click listener
	 */
	public interface OnConnectButtonClickListener {
		public void onConnectClicked(Bundle data);
	}

	private OnConnectButtonClickListener mListener;

	/**
	 * Constructor
	 */
	public ConnectNotifyDialog() {
		// nothing to do
	}

	/**
	 * Attach
	 * set button click listener
	 * @param activity		Activity
	 */
	@Override
	public void onAttach(Activity activity) {
		super.onAttach(activity);

		if (activity instanceof OnConnectButtonClickListener == false) {
			throw new ClassCastException("activity not imprements OnConnectButtonClickListener.");
		}
		mListener = ((OnConnectButtonClickListener) activity);
	}

	/**
	 * Create a dialog
	 * @param savedInstanceState
	 * @return Dialog	Dialog
	 */
	@Override
	public Dialog onCreateDialog(Bundle savedInstanceState) {
		Dialog dialog = new Dialog(getActivity());
		dialog.setContentView(R.layout.connect_notify_dialog);
		dialog.setTitle(getString(R.string.dialog_title_connect_notify));

		// Show SSID
		String ssid = getArguments().getString("SSID");
		TextView mSsidView = (TextView) dialog.findViewById(R.id.textSsid);
		mSsidView.setText(ssid);

		// Connect button click listener
		dialog.findViewById(R.id.buttonConnect).setOnClickListener(new OnClickListener() {

			/**
			 * Connect button click listener
			 * @param v		View
			 */
			@Override
			public void onClick(View v) {
				// Call listener
				if (mListener != null) {
					mListener.onConnectClicked(getArguments());
				}
				dismiss();
			}
		});
		
		// Cancel button click listener
		dialog.findViewById(R.id.buttonCancel).setOnClickListener(new OnClickListener() {

			/**
			 * Cancel button click listener
			 * @param v 	View
			 */
			@Override
			public void onClick(View v) {
				dismiss();
			}
		});
		return dialog;
	}
}
