/*
 * LED color setting preference
 *  for Wi-Fi view & select
 */
package jp.gr.java_conf.j_sota.wifiviewandselect;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.graphics.Color;
import android.preference.Preference;
import android.util.AttributeSet;
import android.view.View;
import android.widget.ImageView;

public class LedColorPreference extends Preference {

	private int mLedColor;
	private int mItemIndex;

	/**
	 * Constructor
	 * @param context	Context
	 * @param attrs		Attribute set
	 */
	public LedColorPreference(Context context, AttributeSet attrs) {
		super(context, attrs);
		setWidgetLayoutResource(R.layout.led_color_preference);
	}

	/**
	 * Constructor
	 * @param context	Context
	 */
	public LedColorPreference(Context context) {
		this(context, null);
	}

	/**
	 * Return a default value
	 * @param array		Array
	 * @param index		Index
	 * @return Object	LED Color
	 */
	@Override
	protected Object onGetDefaultValue(TypedArray array, int index) {
		return array.getColor(index, Color.BLACK);
	}

	/**
	 * Called when draw
	 * @param view		View
	 */
	@Override
	protected void onBindView(View view) {
		final ImageView led = (ImageView) view.findViewById(R.id.imageLed);
		if (led != null) {
			// Show LED
			LedImage ledImage = new LedImage(view.getContext());
			Bitmap ledBitmap = ledImage.getLedImage(mLedColor);
			led.setImageBitmap(ledBitmap);
		}
		super.onBindView(view);
	}

	/**
	 * Set LED color
	 * @param color		Color
	 */
	public void setLedColor(int color) {
		mLedColor = color;
		
		// Update screen
		notifyChanged();
	}

	/**
	 * Set item index
	 * @param index		Index
	 */
	public void setItemIndex(int index) {
		mItemIndex = index;
	}

	/**
	 * Return a item index
	 * @return		index
	 */
	public int getItemIndex() {
		return mItemIndex;
	}
}
